@@ -1,14 +1,16 @@
 # Data::Hopen::G::Goal - A named build goal
 package Data::Hopen::G::Goal;
-use Data::Hopen;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000009'; # TRIAL
+our $VERSION = '0.000011'; # TRIAL
 
 use parent 'Data::Hopen::G::Op';
-#use Class::Tiny qw(_passthrough);
+use Class::Tiny {
+    should_output => true,      # if true, forward the goal's inputs as
+                                # its outputs.
+};
 
-use Data::Hopen::Arrrgs;
+use Data::Hopen;
 use Data::Hopen::Util::Data qw(forward_opts);
 
 # Docs {{{1
@@ -24,19 +26,30 @@ is reserved for the root goal.  Goals usually appear at the end of the build
 graph, but this is not required --- Goal nodes can appear anywhere in the
 graph.
 
+=head1 MEMBERS
+
+=head2 should_output
+
+Boolean, default true.  If false, the goal's outputs are always C<{}> (empty).
+If true, the goal's inputs are passed through as outputs.
+
 =head1 FUNCTIONS
 
 =head2 run
 
-Wraps a L<Data::Hopen::G::CollectOp>'s run function.
+Passes through the inputs if L</should_output> is set.
 
 =cut
 
 # }}}1
 
 sub _run {
-    my ($self, %args) = parameters('self', [qw(; phase generator)], @_);
-    hlog { Goal => $self->name };
+    my ($self, %args) = getparameters('self', [qw(; phase generator)], @_);
+    hlog { Goal => $self->name, ($self->should_output ? 'with' : 'without'),
+            'outputs' };
+
+    return {} unless $self->should_output;
+
     return $self->passthrough(-nocontext=>1, -levels => 'local',
             forward_opts(\%args, {'-'=>1}, qw[phase generator]));
 } #_run()
